@@ -9,4 +9,6 @@ board = pyglet.window.Window(BOARD_WIDTH, BOARD_HEIGHT, caption="PyGL-Astroids")
 batch = pyglet.graphics.Batch()
 asteroids_group = pyglet.graphics.OrderedGroup(0)
 player_group = pyglet.graphics.OrderedGroup(1)
-label_group = pyglet.graphics.OrderedGroup(2)
\ No newline at end of file
+label_group = pyglet.graphics.OrderedGroup(2)
+gameover_group = pyglet.graphics.OrderedGroup(3)
+gameover_group.visible = False
\ No newline at end of file
